Index: include/AdblockPlus/Platform.h |
diff --git a/include/AdblockPlus/Platform.h b/include/AdblockPlus/Platform.h |
index c95204350c3af72af0eee70970636fcbd0101693..e5c45c495ff9f98946e2bdf92ef7a7ae43622c42 100644 |
--- a/include/AdblockPlus/Platform.h |
+++ b/include/AdblockPlus/Platform.h |
@@ -50,6 +50,7 @@ namespace AdblockPlus |
*/ |
LogSystemPtr CreateDefaultLogSystem(); |
+ class IV8IsolateProvider; |
class JsEngine; |
/** |
@@ -93,12 +94,14 @@ namespace AdblockPlus |
~Platform(); |
/** |
- * Ensures that JsEngine is constructed. |
+ * Ensures that JsEngine is constructed. If JsEngine is already present |
+ * then the parameters are ignored. |
* |
* @param appInfo Information about the app, if jsEngine is already present |
* then the value is ignored. |
*/ |
- void SetUpJsEngine(const AppInfo& appInfo = AppInfo()); |
+ void SetUpJsEngine(const AppInfo& appInfo = AppInfo(), std::unique_ptr<IV8IsolateProvider> isolate = nullptr); |
/** |
* Retrieves the `JsEngine` instance. It calls SetUpJsEngine if JsEngine is |
@@ -93,12 +94,14 @@ namespace AdblockPlus |
* |
- * @param appInfo Information about the app, if jsEngine is already present |
- * then the value is ignored. |
+ * @param appInfo Information about the app, |
+ * @param isolate A provider of v8::Isolate, if the value is nullptr then |
+ * a default implementation is used. |
*/ |